Examples
========
These Jupyter Notebooks provide some examples on how to work with ENTMOOT. Their source code can be found
`here <https://github.com/cog-imperial/entmoot/tree/entmoot-v2/docs/notebooks>`_.

.. toctree::
   :maxdepth: 2
   :caption: Contents:

   notebooks/multi_obj_pareto
   notebooks/multi_obj_with_constraints
   notebooks/constraint_classes
   notebooks/single_obj_maximisation
